@@ -22,6 +22,7 @@ import datetime
 import hashlib
 import zipfile
 
+from Iuppiter.Util import run
 from Zephyrus.boilerplate.management.commands import (
     PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH)
 
@@ -38,20 +39,23 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         startPath = options['start']
         dstPath = options['output']
-
+        
         # create project
         machineName = hashlib.md5(
             startPath + str(datetime.datetime.now())).hexdigest()
         machinePath = self.createProject(machineName)
         templateDir = self.unzipTemplates(startPath, machineName)
-
+        
         # build products
         currentPath = os.path.abspath(".")
         os.chdir(machinePath)
+        
         try:
-            os.system(
-                "%s manage.py build_templates %s %s -o" % 
-                (sys.executable, templateDir, dstPath))
+            env = os.environ.copy()
+            del env['DJANGO_SETTINGS_MODULE']
+            cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
+                    templateDir, dstPath)
+            run(cmd, env=env, shell=True, printCmd=True)
         finally:
             # remove project
             os.chdir(currentPath)
